@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
 ########################################################################
 #
-#       License: MIT
 #       Created: September 22, 2010
-#       Author:  Francesc Alted - faltet@gmail.com
+#       Author:  The Blosc development team - blosc@blosc.org
 #
 ########################################################################
 
@@ -92,6 +91,7 @@ def set_nthreads(nthreads):
         raise ValueError("the number of threads cannot be larger than %d" %
                          blosc.MAX_THREADS)
 
+    blosc.nthreads = nthreads
     return _ext.set_nthreads(nthreads)
 
 
